==> huaweicloudsdkgaussdb-3.1.134-py2.py3-none-any.whl: huaweicloudsdkgaussdb/v3/model/star_rocks_instance_info_datastore.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class StarRocksInstanceInfoDatastore:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'id': 'str',
        'type': 'str',
        'version': 'str'
    }

    attribute_map = {
        'id': 'id',
        'type': 'type',
        'version': 'version'
    }

    def __init__(self, id=None, type=None, version=None):
        """StarRocksInstanceInfoDatastore

        The model defined in huaweicloud sdk

        :param id: 数据库ID。
        :type id: str
        :param type: 数据库类型。
        :type type: str
        :param version: 数据库版本。
        :type version: str
        """
        
        

        self._id = None
        self._type = None
        self._version = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if type is not None:
            self.type = type
        if version is not None:
            self.version = version

    @property
    def id(self):
        """Gets the id of this StarRocksInstanceInfoDatastore.

        数据库ID。

        :return: The id of this StarRocksInstanceInfoDatastore.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this StarRocksInstanceInfoDatastore.

        数据库ID。

        :param id: The id of this StarRocksInstanceInfoDatastore.
        :type id: str
        """
        self._id = id

    @property
    def type(self):
        """Gets the type of this StarRocksInstanceInfoDatastore.

        数据库类型。

        :return: The type of this StarRocksInstanceInfoDatastore.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this StarRocksInstanceInfoDatastore.

        数据库类型。

        :param type: The type of this StarRocksInstanceInfoDatastore.
        :type type: str
        """
        self._type = type

    @property
    def version(self):
        """Gets the version of this StarRocksInstanceInfoDatastore.

        数据库版本。

        :return: The version of this StarRocksInstanceInfoDatastore.
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this StarRocksInstanceInfoDatastore.

        数据库版本。

        :param version: The version of this StarRocksInstanceInfoDatastore.
        :type version: str
        """
        self._version = version

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, StarRocksInstanceInfoDatastore):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkgaussdb-3.1.158-py2.py3-none-any.whl: huaweicloudsdkgaussdb/v3/model/star_rocks_instance_info_datastore.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class StarRocksInstanceInfoDatastore:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'id': 'str',
        'type': 'str',
        'version': 'str'
    }

    attribute_map = {
        'id': 'id',
        'type': 'type',
        'version': 'version'
    }

    def __init__(self, id=None, type=None, version=None):
        r"""StarRocksInstanceInfoDatastore

        The model defined in huaweicloud sdk

        :param id: 数据库ID。
        :type id: str
        :param type: 数据库类型。
        :type type: str
        :param version: 数据库版本。
        :type version: str
        """
        
        

        self._id = None
        self._type = None
        self._version = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if type is not None:
            self.type = type
        if version is not None:
            self.version = version

    @property
    def id(self):
        r"""Gets the id of this StarRocksInstanceInfoDatastore.

        数据库ID。

        :return: The id of this StarRocksInstanceInfoDatastore.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        r"""Sets the id of this StarRocksInstanceInfoDatastore.

        数据库ID。

        :param id: The id of this StarRocksInstanceInfoDatastore.
        :type id: str
        """
        self._id = id

    @property
    def type(self):
        r"""Gets the type of this StarRocksInstanceInfoDatastore.

        数据库类型。

        :return: The type of this StarRocksInstanceInfoDatastore.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        r"""Sets the type of this StarRocksInstanceInfoDatastore.

        数据库类型。

        :param type: The type of this StarRocksInstanceInfoDatastore.
        :type type: str
        """
        self._type = type

    @property
    def version(self):
        r"""Gets the version of this StarRocksInstanceInfoDatastore.

        数据库版本。

        :return: The version of this StarRocksInstanceInfoDatastore.
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version):
        r"""Sets the version of this StarRocksInstanceInfoDatastore.

        数据库版本。

        :param version: The version of this StarRocksInstanceInfoDatastore.
        :type version: str
        """
        self._version = version

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, StarRocksInstanceInfoDatastore):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
